@@ -1,6 +1,9 @@
+"""Transformers module."""
+
 from rdt.transformers.base import BaseTransformer
 from rdt.transformers.boolean import BooleanTransformer
-from rdt.transformers.categorical import CategoricalTransformer
+from rdt.transformers.categorical import (
+    CategoricalTransformer, LabelEncodingTransformer, OneHotEncodingTransformer)
 from rdt.transformers.datetime import DatetimeTransformer
 from rdt.transformers.null import NullTransformer
 from rdt.transformers.numerical import NumericalTransformer
@@ -12,8 +15,11 @@ __all__ = [
     'DatetimeTransformer',
     'NumericalTransformer',
     'NullTransformer',
+    'OneHotEncodingTransformer',
+    'LabelEncodingTransformer',
 ]
 
+
 TRANSFORMERS = {
     transformer.__name__: transformer
     for transformer in BaseTransformer.__subclasses__()
@@ -52,7 +58,8 @@ def load_transformer(transformer):
 
 
 def load_transformers(transformers):
-    """
+    """Load a dict of transfomers from a dict specification.
+
     >>> nt = NumericalTransformer(dtype=float)
     >>> transformers = {
     ...     'a': nt,
